@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2014-07-31'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2014-08-07'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 
@@ -131,6 +131,7 @@ sub do_completion {
         completion      => sub {
             my %args = @_;
             my $type = $args{type};
+
             # user specifies custom completion routine, so use that first
             if ($self->completion) {
                 my $res = $self->completion(%args);
@@ -138,12 +139,12 @@ sub do_completion {
             }
             # if subcommand name has not been supplied and we're at arg#0,
             # complete subcommand name
-            if ($self->subcommands && !$r->{subcommand_name_from} &&
+            if ($self->subcommands && $r->{subcommand_name_from} ne '--cmd' &&
                     $args{type} eq 'arg' && $args{argpos}==0) {
                 require Complete::Util;
                 return Complete::Util::complete_array_elem(
-                    array => keys %{ $self->list_subcommands },
-                    word=>$words->[$cword]);
+                    array => [keys %{ $self->list_subcommands }],
+                    word  => $words->[$cword]);
             }
 
             # otherwise let periscomp do its thing
@@ -379,7 +380,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.11 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2014-07-31.
+This document describes version 0.12 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2014-08-07.
 
 =for Pod::Coverage ^(.+)$
 
